@@ -2,11 +2,11 @@ package POD2::ES;
 use utf8;
 use strict;
 use warnings;
-use open ':locale';
+use open ':utf8';
 use base 'Exporter';
 use base 'POD2::Base';
 
-our $VERSION = '5.22.0.1';
+our $VERSION = '5.22.0.2';
 
 our @EXPORT = qw(print_pod print_pods);
 
@@ -100,11 +100,11 @@ sub print_pods {
 __END__
 =encoding utf8
 
-=head1 NOMBRE
+=head1 NAME
 
 POD2::ES - Documentación de Perl en español
 
-=head1 SINOPSIS
+=head1 SYNOPSIS
 
   $ perldoc POD2::ES::<nombre_pod>
 
@@ -121,7 +121,7 @@ POD2::ES - Documentación de Perl en español
   $pod2->print_pod('perlfunc');
                                                                                           
 
-=head1 DESCRIPCIÓN
+=head1 DESCRIPTION
 
 Este módulo contiene los documentos revisados hasta la fecha del proyecto de 
 traducción al español de la documentación básica de Perl, que se aloja en 
@@ -203,7 +203,7 @@ solicita a C<perldoc> mediante la opción C<-f>.
 =back
 
 
-=head1 NOTAS SOBRE LA TRADUCCIÓN
+=head1 NOTES ABOUT THE TRANSLATION
 
 Para este proyecto hemos tomado las siguientes decisiones:
 
@@ -247,7 +247,7 @@ Latinoamérica.
 =back
 
 
-=head1 AUTORES
+=head1 AUTHOR
 
 =over
 
@@ -261,18 +261,18 @@ Latinoamérica.
 
 =back
 
-=head1 PROYECTO
+=head1 REPOSITORY
 
 Encontrará más información sobre el proyecto en
 L<https://github.com/perldocES/perldoc-es>.
 
 
-=head1 VEA TAMBIÉN
+=head1 SEE ALSO
 
 L<POD2::RU>, L<POD2::PT_BR>, L<POD2::IT>, L<POD2::FR>, L<POD2::LT>.
 
 
-=head1 DONATIVOS
+=head1 DONATIONS
 
 Por el elevado volumen de trabajo que representa y su larga duración, el
 proyecto de traducción de la documentación de Perl requiere un esfuerzo
@@ -284,7 +284,7 @@ alta la moral. Todo será bienvenido.
 
 
 
-=head1 ERRORES
+=head1 BUGS
 
 Puede notificar errores (bugs) o solicitar funcionalidad a través de la
 dirección de correo electrónico C<bug-pod2-es at rt.cpan.org> o de la interfaz
@@ -293,7 +293,7 @@ comunicarán automáticamente los cambios relacionados con los errores
 notificados o la funcionalidad solicitada.
 
 
-=head1 SOPORTE
+=head1 SUPPORT
 
 Para ver la documentación de este módulo, utilice el comando perldoc.
 
@@ -323,7 +323,7 @@ L<http://search.cpan.org/dist/POD2-ES/>
 =back
 
 
-=head1 AGRADECIMIENTOS
+=head1 ACKNOWLEDGMENTS
 
 Los autores desean expresar su gratitud al equipo de desarrollo de OmegaT,
 la herramienta utilizada para la traducción.
@@ -331,7 +331,7 @@ la herramienta utilizada para la traducción.
 Proyecto OmegaT: L<http://omegat.org/>
 
 
-=head1 LICENCIA Y COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
 
 Copyright (C) 2011-2016 Equipo de Perl en Español.
 
